<?php
/**
 * @file
 * Contains \Drupal\scheduled_updates\GlobalUpdateRunner.
 */


namespace Drupal\scheduled_updates;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\scheduled_updates\Entity\ScheduledUpdateType;
use Drupal\scheduled_updates\Plugin\UpdateRunnerInterface;
use Drupal\scheduled_updates\Plugin\UpdateRunnerManager;

/**
 * A service that runs all available updaters
 */
class GlobalUpdateRunner {

  /** @var \Drupal\Core\Entity\EntityFieldManagerInterface  */
  protected $entityFieldManager;

  /** @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface  */
  protected $entityTypeBundleInfo;

  /** @var \Drupal\scheduled_updates\Plugin\UpdateRunnerManager  */
  protected $runnerManager;

  /**
   * UpdateRunner constructor.
   *
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entityFieldManager
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entityTypeBundleInfo
   * @param \Drupal\scheduled_updates\Plugin\UpdateRunnerManager $runnerManager
   */
  public function __construct(EntityFieldManagerInterface $entityFieldManager, EntityTypeBundleInfoInterface $entityTypeBundleInfo, UpdateRunnerManager $runnerManager) {
    $this->entityFieldManager = $entityFieldManager;
    $this->entityTypeBundleInfo = $entityTypeBundleInfo;
    $this->runnerManager = $runnerManager;
  }

  public function runAllUpdates() {
    $bundles = $this->entityTypeBundleInfo->getBundleInfo('scheduled_update');
    foreach ($bundles as $bundle => $bundle_info) {
      /** @var ScheduledUpdateType $updater */
      $updater = ScheduledUpdateType::load($bundle);
      $runner_settings = $updater->getUpdateRunner();
      $runner_settings['updater_type'] = $bundle;

      /** @var UpdateRunnerInterface $runner */
      if ($runner = $this->runnerManager->createInstance($runner_settings['id'], $runner_settings)) {
        $runner->addUpdatesToQueue();
        $runner->runUpdatesInQueue();
      }

    }

  }
}
