<?php
/**
 * @file Contains Drupal\scheduled_updates\Plugin\UpdateRunnerInterface.
 */

namespace Drupal\scheduled_updates\Plugin;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginFormInterface;

interface UpdateRunnerInterface extends PluginInspectionInterface, ContainerFactoryPluginInterface, PluginFormInterface {

  // Constants for Invalid Updates
  const INVALID_DELETE = 'DELETE';

  const INVALID_REQUEUE = 'REQUEUE';

  const INVALID_ARCHIVE = 'ARCHIVE';

  // Constants for behavior after updates are run.
  const AFTER_DELETE = 'DELETE';
  const AFTER_ARCHIVE = 'ARCHIVE';

  // Constants for revisions.
  const REVISIONS_BUNDLE_DEFAULT = 'BUNDLE_DEFAULT';
  const REVISIONS_YES = 'YES';
  const REVISIONS_NO = 'NO';

  // Constants for update user
  const USER_UPDATE_RUNNER = 'USER_UPDATE_RUNNER';
  const USER_OWNER = 'USER_OWNER';
  const USER_REVISION_OWNER = 'USER_REVISION_OWNER';
  const USER_UPDATE_OWNER = 'USER_UPDATE_OWNER';

  /**
   * Add all updates to queue.
   */
  public function addUpdatesToQueue();

  /**
   * Get the Queue for this Update Runner.
   *
   * @return \Drupal\Core\Queue\QueueInterface
   *   The queue object.
   */
  public function getQueue();
  /**
   * Run all updates that are in the queue.
   */
  public function runUpdatesInQueue();

  /**
   * Get how this runner should handle invalid entity updates.
   *
   * @return string
   */
  public function getInvalidUpdateBehavior();

}
